{% extends "base.html" %}
{% block title %}{{ article.title }}{%endblock%}
{% block content %}
    <h1>{{ article.title }}</h1>
    <div class="info">
    {% if article.author %}
     By <a class="url fn" href="#">{{ article.author }}</a>
    {% endif %}
     on <a>{{ article.date.strftime('%a %d %B %Y') }}</a>
     about <a href="{{ SITEURL }}/category/{{ article.category }}.html">{{ article.category }}</a>
    </div>
    {{ article.content }}
{% endblock %}
